You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@felix.apache.org by ri...@apache.org on 2009/07/22 17:42:33 UTC

svn commit: r796772 - in /felix/sandbox/rickhall/bnd-test/org.apache.felix.framework.bootdelegation: bnd.bnd src/org/apache/felix/framework/bootdelegation/BootDelegationTest.java

Author: rickhall
Date: Wed Jul 22 15:42:33 2009
New Revision: 796772

URL: http://svn.apache.org/viewvc?rev=796772&view=rev
Log:
Add test for invalid wildcard. (FELIX-1400)

Modified:
    felix/sandbox/rickhall/bnd-test/org.apache.felix.framework.bootdelegation/bnd.bnd
    felix/sandbox/rickhall/bnd-test/org.apache.felix.framework.bootdelegation/src/org/apache/felix/framework/bootdelegation/BootDelegationTest.java

Modified: felix/sandbox/rickhall/bnd-test/org.apache.felix.framework.bootdelegation/bnd.bnd
URL: http://svn.apache.org/viewvc/felix/sandbox/rickhall/bnd-test/org.apache.felix.framework.bootdelegation/bnd.bnd?rev=796772&r1=796771&r2=796772&view=diff
==============================================================================
--- felix/sandbox/rickhall/bnd-test/org.apache.felix.framework.bootdelegation/bnd.bnd (original)
+++ felix/sandbox/rickhall/bnd-test/org.apache.felix.framework.bootdelegation/bnd.bnd Wed Jul 22 15:42:33 2009
@@ -7,6 +7,6 @@
 
 	
 -runproperties: report=true, \
-        org.osgi.framework.bootdelegation="javax.swing,javax.swing.text.html,javax.swing.text.html.*"
+        org.osgi.framework.bootdelegation="javax.swing,javax.swing.text.html,javax.swing.text.html.*,org.omg*"
 
 Test-Cases = ${classes;extending;*TestCase}

Modified: felix/sandbox/rickhall/bnd-test/org.apache.felix.framework.bootdelegation/src/org/apache/felix/framework/bootdelegation/BootDelegationTest.java
URL: http://svn.apache.org/viewvc/felix/sandbox/rickhall/bnd-test/org.apache.felix.framework.bootdelegation/src/org/apache/felix/framework/bootdelegation/BootDelegationTest.java?rev=796772&r1=796771&r2=796772&view=diff
==============================================================================
--- felix/sandbox/rickhall/bnd-test/org.apache.felix.framework.bootdelegation/src/org/apache/felix/framework/bootdelegation/BootDelegationTest.java (original)
+++ felix/sandbox/rickhall/bnd-test/org.apache.felix.framework.bootdelegation/src/org/apache/felix/framework/bootdelegation/BootDelegationTest.java Wed Jul 22 15:42:33 2009
@@ -33,8 +33,8 @@
     public void testBootDelegation() throws Exception
     {
         // This test has configured the framework to boot delegate
         // java.* (by default), javax.swing, javax.swing.text.html, and
         // javax.swing.text.html.*.
         Class clazz = null;
 
         // Should NOT throw an exception.
@@ -93,5 +93,15 @@
         {
             // Ignore.
         }
+        // Should throw an exception.
+        try
+        {
+            clazz = Class.forName("org.omg.CORBA.Current");
+            assertTrue("Class should not be visible: " + clazz, false);
+        }
+        catch (Exception ex)
+        {
+            // Ignore.
+        }
     }
 }
\ No newline at end of file
@@ -33,8 +33,8 @@
     {
         // This test has configured the framework to boot delegate
-        // java.* (by default), javax.swing, javax.swing.text.html, and
-        // javax.swing.text.html.*.
+        // java.* (by default), javax.swing, javax.swing.text.html,
+        // javax.swing.text.html.*, and org.omg*.
         Class clazz = null;
 